@@ -1,7 +1,7 @@
 """A set of utility functions for CodecCub."""
 
-from codec_cub.common import first_token
 from funcy_bear.constants.characters import DASH, UNDERSCORE
+from funcy_bear.ops.strings.manipulation import first_item
 
 
 def is_bare_identifier(s: str) -> bool:
@@ -15,7 +15,7 @@ def is_bare_identifier(s: str) -> bool:
     """
     if not s:
         return False
-    first: str = first_token(s)
+    first: str = first_item(s)
     if not (first.isalpha() or first == UNDERSCORE):
         return False
     return all(ch.isalnum() or ch in {UNDERSCORE, DASH} for ch in s[1:])
